==> plantit_cli-0.1.46-py3-none-any.whl: plantit_cli/executor/executor.py <==
import os
import subprocess
import traceback
from abc import ABC
from os.path import join

from plantit_cli.exceptions import PlantitException
from plantit_cli.plan import Plan
from plantit_cli.store.terrain_store import TerrainStore
from plantit_cli.utils import update_status, run_container_for_directory, run_containers_for_files, \
    run_container


class Executor(ABC):
    def __store(self, run: Plan):
        return TerrainStore(run=run)

    def __clone_repo(self, run: Plan):
        if subprocess.run(f"git clone {run.clone}",
                             stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE,
                             shell=True).returncode != 0:
            raise PlantitException(f"Failed to clone repository '{run.clone}'")
        else:
            update_status(run, 3, f"Cloned repository '{run.clone}'")

    def __pull_input(self, run: Plan) -> str:
        store = self.__store(run)
        directory = join(run.workdir, 'input')
        os.makedirs(directory, exist_ok=True)
        store.pull(directory, run.input['pattern'] if 'pattern' in run.input else None)
        update_status(run, 3, f"Pulled input(s)")
        return directory

    def __push_output(self, run: Plan):
        store = self.__store(run)
        local_path = join(run.workdir, run.output['from']) if 'from' in run.output else run.workdir
        store.upload_directory(local_path, (run.output['pattern'] if run.output['pattern'] != '' else None) if 'pattern' in run.output else None)
        update_status(run, 3, f"Pushed output(s)")

    def execute(self, run: Plan):
        update_status(run, 3, f"Starting '{run.identifier}'...")
        try:
            if run.clone is not None and run.clone is not '':
                self.__clone_repo(run)

            if run.input:
                print(f"Pulling inputs for '{run.identifier}'...")
                input_directory = self.__pull_input(run)
                if run.input['kind'].lower() == 'directory':
                    run_container_for_directory(run, input_directory)
                elif run.input['kind'].lower() == 'file':
                    run_containers_for_files(run, input_directory)
                else:
                    raise ValueError(f"'input.kind' must be either 'file' or 'directory'")
            else:
                run_container(run)

            if run.output:
                print(f"Pushing outputs for '{run.identifier}'...")
                self.__push_output(run)

            update_status(run, 1, f"Run '{run.identifier}' completed.")
        except Exception:
            update_status(run, 2, f"Run '{run.identifier}' failed: {traceback.format_exc()}")
            return

==> plantit_cli-0.1.79-py3-none-any.whl: plantit_cli/executor/executor.py <==
import os
import subprocess
import traceback
from abc import ABC
from os.path import join

from plantit_cli.exceptions import PlantitException
from plantit_cli.config import Config
from plantit_cli.store.terrain_store import TerrainStore
from plantit_cli.utils import update_status, run_container_for_directory, run_containers_for_files, \
    run_container


class Executor(ABC):
    def __store(self, run: Config):
        return TerrainStore(run=run)

    def __clone_repo(self, run: Config):
        if subprocess.run(f"git clone {run.clone}",
                             stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE,
                             shell=True).returncode != 0:
            raise PlantitException(f"Failed to clone repository '{run.clone}'")
        else:
            update_status(run, 3, f"Cloned repository '{run.clone}'")

    def __pull_input(self, run: Config) -> str:
        store = self.__store(run)
        directory = join(run.workdir, 'input')
        os.makedirs(directory, exist_ok=True)
        store.pull(directory, run.input['pattern'] if 'pattern' in run.input else None)
        update_status(run, 3, f"Pulled input(s)")
        return directory

    def __push_output(self, run: Config):
        store = self.__store(run)
        local_path = join(run.workdir, run.output['from']) if 'from' in run.output else run.workdir
        store.upload_directory(local_path, (run.output['pattern'] if run.output['pattern'] != '' else None) if 'pattern' in run.output else None)
        update_status(run, 3, f"Pushed output(s)")

    def execute(self, run: Config):
        update_status(run, 3, f"Starting '{run.identifier}'...")
        try:
            if run.clone is not None and run.clone is not '':
                self.__clone_repo(run)

            if run.input:
                print(f"Pulling inputs for '{run.identifier}'...")
                input_directory = self.__pull_input(run)
                if run.input['kind'].lower() == 'directory':
                    run_container_for_directory(run, input_directory)
                elif run.input['kind'].lower() == 'file':
                    run_containers_for_files(run, input_directory)
                else:
                    raise ValueError(f"'input.kind' must be either 'file' or 'directory'")
            else:
                run_container(run)

            if run.output:
                print(f"Pushing outputs for '{run.identifier}'...")
                self.__push_output(run)

            update_status(run, 1, f"Run '{run.identifier}' completed.")
        except Exception:
            update_status(run, 2, f"Run '{run.identifier}' failed: {traceback.format_exc()}")
            return
